﻿using Performance.DtoModels;
using System;
using System.Collections.Generic;
using System.Text;

namespace Performance.Services
{
    /// <summary>
    /// 工厂
    /// </summary>
    public class PerSheetDataFactory
    {
        /// <summary>
        /// 构建excel读取
        /// </summary>
        /// <param name="sheetType"></param>
        /// <returns></returns>
        public static IPerSheetDataRead GetDataRead(SheetType sheetType)
        {
            IPerSheetDataRead dataread = null;
            switch (sheetType)
            {
                case SheetType.Employee:
                    dataread = new PerSheetDataReadEmployee();
                    break;
                case SheetType.Income:
                    dataread = new PerSheetDataReadIncome();
                    break;
                case SheetType.OtherIncome:
                    dataread = new PerSheetDataReadOtherIncome();
                    break;
                case SheetType.Expend:
                    dataread = new PerSheetDataReadExpend();
                    break;
                case SheetType.Overtime:
                    dataread = new PerSheetDataReadOvertime();
                    break;
                case SheetType.Workload:
                    dataread = new PerSheetDataReadWorkload();
                    break;
                case SheetType.UnifyUnit:
                    dataread = new PerSheetDataReadUnifyUnit();
                    break;
            }
            return dataread;
        }

        /// <summary>
        /// 构建excel计算
        /// </summary>
        /// <param name="sheetType"></param>
        /// <returns></returns>
        public static IPerSheetDataCompute GetDataCompute(SheetType sheetType)
        {
            IPerSheetDataCompute dataCompute = null;
            switch (sheetType)
            {
                case SheetType.Income:
                case SheetType.OtherIncome:
                case SheetType.Expend:
                    dataCompute = new PerSheetDataComputeEconomic();
                    break;
                case SheetType.Workload:
                    dataCompute = new PerSheetDataComputeWorkload();
                    break;
                    //case SheetType.Overtime:
                    //    dataCompute = new PerSheetDataReadOvertime();
                    //    break;
                    //case SheetType.UnifyUnit:
                    //    dataread = new PerSheetDataReadUnifyUnit();
                    //    break;
            }
            return dataCompute;
        }
    }
}
