﻿using Performance.DtoModels;
using Performance.Infrastructure;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;

namespace Performance.Services
{
    /// <summary>
    /// 科室经济核算汇总表 （收入/其他收入/支出）
    /// </summary>
    public class PerSheetDataComputeEconomic : IPerSheetDataCompute
    {
        /// <summary>
        /// 计算科室经济核算汇总表
        /// </summary>
        /// <param name="excel"></param>
        /// <returns></returns>
        public PerSheet ProcessCompute(PerSheet sheet)
        {
            var dataList = sheet.PerData.Select(t => (PerData)t);
            int phead = 0;
            //修改cell坐标，为新增合计预留位置
            foreach (var header in sheet.PerHeader)
            {
                if (header.IsHasChildren)
                {
                    header.PointCell = header.PointCell + phead;
                    header.Children.ForEach(item => item.PointCell = item.PointCell + phead);
                    phead = phead + 2;
                }
            }

            List<PerHeader> perHeadList = new List<PerHeader>();
            List<PerData> perDataList = new List<PerData>();
            //插入合计结果
            foreach (var header in sheet.PerHeader)
            {
                if (header.IsHasChildren)
                {
                    var maxcell = header.Children.Max(t => t.PointCell);
                    var parentHead = new PerHeader(0, maxcell + 1, $" {header.CellValue}合计", 0, 1, 2, new List<PerHeader>());
                    perHeadList.Add(parentHead);

                    var typeClass = dataList.Where(t => header.Children.Select(s => s.CellValue).Contains(t.TypeName));
                    int pointcell = 0;
                    foreach (var group in typeClass.GroupBy(t => t.UnitType))
                    {
                        pointcell++;
                        parentHead.Children.Add(new PerHeader(1, maxcell + pointcell, group.Key, 1, 1, 1, null));
                        foreach (var t in group.Where(t => t.CellValue.HasValue && t.CellValue.Value > 0).GroupBy(t => t.AccountingUnit))
                        {
                            var sd = new PerData
                            {
                                UnitType = group.Key,
                                AccountingUnit = t.Key,
                                CellValue = t.Sum(s => s.CellValue),
                                TypeName = group.Key,
                                RowNumber = 0,
                                IsSum = 1,
                                PointCell = maxcell + pointcell,
                                ComputRule = t.Select(s => s.ComputRule).Distinct().First()
                            };
                        }
                        var ds = group.Where(t => t.CellValue.HasValue && t.CellValue.Value > 0)
                            .GroupBy(t => t.AccountingUnit).Select(t => new PerData
                            {
                                UnitType = group.Key,
                                AccountingUnit = t.Key,
                                CellValue = t.Sum(s => s.CellValue),
                                TypeName = group.Key,
                                RowNumber = 0,
                                IsSum = 1,
                                PointCell = maxcell + pointcell,
                                ComputRule = t.Select(s => s.ComputRule).Distinct().First()
                            });
                        perDataList.AddRange(ds);
                    }
                }
            }
            sheet.PerHeader.AddRange(perHeadList);
            sheet.PerData.AddRange(perDataList);
            return sheet;
        }
    }
}
