﻿using NPOI.SS.UserModel;
using Performance.DtoModels;
using Performance.Infrastructure;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Performance.Services
{
    /// <summary>
    /// 工作量
    /// </summary>
    public class PerSheetDataReadWorkload : IPerSheetDataRead
    {
        public PerSheetPoint Point => new PerSheetPoint
        {
            HeaderFirstRowNum = 1,
            HeaderLastRowNum = 2,
            HeaderFirstCellNum = 1,
            DataFirstRowNum = 4,
            AccountingUnit = new List<AccountingUnit>
            {
               new AccountingUnit
               {
                    AccountingUnitCellNum = 0,
                    DeptCellNum = 1,
                    FactorRow = 3
               }
            }
        };

        public List<IPerData> ReadData(ISheet sheet, List<PerHeader> perHeader)
        {
            List<IPerData> dataList = new List<IPerData>();

            var unit = Point.AccountingUnit.First();
            //查询除了 核算单元  科室名称 有效数据列头位置
            var vhead = perHeader.Where(t => t.PointCell != unit.AccountingUnitCellNum && t.PointCell != unit.DeptCellNum).OrderBy(t => t.PointCell);

            for (int r = Point.DataFirstRowNum.Value; r < sheet.LastRowNum + 1; r++)
            {
                var row = sheet.GetRow(r);
                for (int c = 0; c < vhead.Count(); c++)
                {
                    //获取当前核算单元名称
                    var accountingUnit = row.GetCell(unit.AccountingUnitCellNum.Value)?.ToString();
                    //核算单元空值跳过
                    if (string.IsNullOrEmpty(accountingUnit))
                        continue;

                    var athead = vhead.ElementAt(c);

                    PerData data = new PerData
                    {
                        RowNumber = r,
                        AccountingUnit = accountingUnit,
                        Department = row.GetCell(unit.DeptCellNum.Value)?.ToString(),
                        TypeName = athead?.CellValue,
                        CellValue = ConvertHelper.To<decimal?>(row.GetCell(athead.PointCell)?.ToString()),
                        Annotation = row.GetCell(athead.PointCell)?.CellComment?.String?.String,
                        UnitType = unit.UnitType,
                        FactorValue = ConvertHelper.To<decimal?>(sheet.GetRow(unit.FactorRow.Value).GetCell(athead.PointCell)?.ToString()),
                        IsFactor = true,
                    };
                    if (sheet.SheetName.Contains("医生组"))
                        data.UnitType = "医生组";
                    else if (sheet.SheetName.Contains("护理组"))
                        data.UnitType = "护理组";

                    dataList.Add(data);
                }
            }

            return dataList;
        }
    }
}
